==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/liblxqt/liblxqt_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation type="obsolete">Eklenti ekle</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="vanished">Ara:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation type="obsolete">Eklenti ekle</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Etkileşim</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">Versiyon: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Qt teknolojilerini temel alan gelişmiş, kullanımı kolay ve hızlı masaüstü ortamı.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Telif Hakkı: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Anasayfa: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Lisans: %1</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQt tüm dünyadaki çeviri ekiplerinin çalışmalarına sayesinde birçok dil çevrilir.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Hayır</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;LXQt Masaüstü araç kutusu - Teknik bilgi&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">Versiyon</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">Hata Ayıklama Oluştur</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">Sistem Yapılandırması</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">Paylaşılan Dizin</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">Çeviriler</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Kullanıcı Dizinleri&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Xdg Ev Verisi Dizini</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Xdg Ev Yapılandırması Dizini</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Xdg Veri Dizinleri</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Xdg Ev Önbelleği Dizini</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Xdg Ev Çalışma Zamanı Dizini</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Xdg Otomatik Başlatma Dizinleri</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Xdg Ev Otomatik Başlatma Dizini</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation type="unfinished">LXQt Güç Yöneticisi Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation type="unfinished">Uykuya alma başarısız oldu.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Bildirimleri geriye al</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>Uyku</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>Askıya Al</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>Bilgisayarı Kapat</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQt Oturum Askıya Alma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Bilgisayarınızı gerçekten askıya almak istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde askıya alır. Güç gittiği takdirde sistem durumu saklanmaz.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt Oturum Uyku Kipi</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Bilgisayarınızı gerçekten uyku kipine geçirmek istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde uyku kipine alır. Güç gittiği takdirde sistem durumu korunur.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt Oturum Yeniden Başlatma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Bilgisayarınızı gerçekten yeniden başlatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt Oturum Kapatma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Bilgisayarınızı gerçekten kapatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt Oturumu Kapatma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Oturumunuzu gerçekten kapatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt Güç Yöneticisi Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>Uykuya alma başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>Askıya alma başarısız oldu.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="83"/>
        <location filename="../../lxqtscreensaver.cpp" line="89"/>
        <location filename="../../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>Ekran Koruyucusu Etkinleştirme Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver çöktüğünden başlatılamadı.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver düzgün biçimde kurulmamış,</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver başlatılamıyor.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver argümanlarında sözdizimi hatası.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Ekran koruyucu başlatılırken hata oluştu. xscreensaver uygulamasının kurulu ve çalışmakta olduğundan emin olun.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Ekran koruyucu başlatılırken hata oluştu. &apos;etkinleştirme&apos; eylemi başarısız oldu. xscreensaver uygulamasının kurulu ve çalışmakta olduğundan emin olun.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">Ekran Koruyucu başlarken bir hata oluştur. Bilinmeyen hata - xdg-screensaver=%1 den okunamayan geri dönüş değeri.</translation>
    </message>
</context>
<context>
    <name>LXQt::ShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Temizle</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Yok</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>Güç Yöneticisi Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface geçersiz</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Güç Yöneticisi Hatası (D-Bus çağrısı)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">LXQt Hakkında</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">Hakkında</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Yazarlar</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Teşekkürler</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Çeviriler</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Teknik Bilgi</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/liblxqt/liblxqt_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation type="obsolete">Eklenti ekle</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="vanished">Ara:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation type="obsolete">Eklenti ekle</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Etkileşim</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">Versiyon: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Qt teknolojilerini temel alan gelişmiş, kullanımı kolay ve hızlı masaüstü ortamı.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Telif Hakkı: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Anasayfa: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Lisans: %1</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQt tüm dünyadaki çeviri ekiplerinin çalışmalarına sayesinde birçok dil çevrilir.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Hayır</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;LXQt Masaüstü araç kutusu - Teknik bilgi&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">Versiyon</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">Hata Ayıklama Oluştur</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">Sistem Yapılandırması</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">Paylaşılan Dizin</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">Çeviriler</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Kullanıcı Dizinleri&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Xdg Ev Verisi Dizini</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Xdg Ev Yapılandırması Dizini</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Xdg Veri Dizinleri</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Xdg Ev Önbelleği Dizini</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Xdg Ev Çalışma Zamanı Dizini</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Xdg Otomatik Başlatma Dizinleri</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Xdg Ev Otomatik Başlatma Dizini</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt Güç Yöneticisi Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation>Uykuya alma başarısız oldu.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Bildirimleri geriye al</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>Uyku</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>Askıya Al</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>Bilgisayarı Kapat</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQt Oturum Askıya Alma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Bilgisayarınızı gerçekten askıya almak istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde askıya alır. Güç gittiği takdirde sistem durumu saklanmaz.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt Oturum Uyku Kipi</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Bilgisayarınızı gerçekten uyku kipine geçirmek istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde uyku kipine alır. Güç gittiği takdirde sistem durumu korunur.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt Oturum Yeniden Başlatma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Bilgisayarınızı gerçekten yeniden başlatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt Oturum Kapatma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Bilgisayarınızı gerçekten kapatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt Oturumu Kapatma</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Oturumunuzu gerçekten kapatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt Güç Yöneticisi Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>Uykuya alma başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>Askıya alma başarısız oldu.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation>Ekran Koruyucu Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="83"/>
        <location filename="../../lxqtscreensaver.cpp" line="89"/>
        <location filename="../../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>Ekran Koruyucusu Etkinleştirme Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Ekran Koruyucu başlarken bir hata oluştur. Bilinmeyen hata - xdg-screensaver=%1 den okunamayan geri dönüş değeri.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver çöktüğünden başlatılamadı.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver düzgün biçimde kurulmamış,</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver başlatılamıyor.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Ekran koruyucu başlatılırken hata oluştu. xdg-screensaver argümanlarında sözdizimi hatası.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Ekran koruyucu başlatılırken hata oluştu. xscreensaver uygulamasının kurulu ve çalışmakta olduğundan emin olun.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Ekran koruyucu başlatılırken hata oluştu. &apos;etkinleştirme&apos; eylemi başarısız oldu. xscreensaver uygulamasının kurulu ve çalışmakta olduğundan emin olun.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">Ekran Koruyucu başlarken bir hata oluştur. Bilinmeyen hata - xdg-screensaver=%1 den okunamayan geri dönüş değeri.</translation>
    </message>
</context>
<context>
    <name>LXQt::ShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Temizle</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Yok</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>Güç Yöneticisi Hatası</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface geçersiz</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Güç Yöneticisi Hatası (D-Bus çağrısı)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">LXQt Hakkında</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">Hakkında</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Yazarlar</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Teşekkürler</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Çeviriler</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Teknik Bilgi</translation>
    </message>
</context>
</TS>
